@@ -1,8 +1,8 @@
 !== 顼
 !
 ! Authors::   Eizi TOYODA, Yasuhiro MORIKAWA
-! Version::   $Id: dc_error.f90,v 1.12 2006/12/24 20:20:24 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20070101 $
+! Version::   $Id: dc_error.f90,v 1.13 2007/01/08 06:30:37 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070116 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -41,8 +41,9 @@ module dc_error
   ! ⥸塼Ѥ뤫 include 'netcdf.inc' ԤʸԤϿ侩ޤˡ
   ! <b><tt>GT_E</tt></b> ǻϤޤ̾ˤĤƤ dc_error
   ! ⥸塼ѤƤ
-  ! ޤ <b><tt>USR_E</tt></b> ǻϤޤ̾ϳơΥ桼
-  ! ɤ顼ɤǤ
+  ! ޤ <b><tt>USR_ERRNO</tt></b> ֤꾮ͤϡ
+  ! ơΥ桼Ŭ顼ɤ
+  ! Ѥ뤿˶Ƥޤ
   !
   ! 顼ǤϤʤ֤ɽ󥨥顼ɤ *DC_NOERR* Ǥ
   !
@@ -286,18 +287,14 @@ module dc_error
   !
   !=== 桼ѥ顼
   !
-  ! ʲΥ顼ɤޤ -1000 ⾮顼ɤϡ
+  ! -1000 ⾮顼ɤϡ
   ! gt4f90io ξ̤ΥץबѤ륨顼ɤȤƶƤޤ
   !
   ! <b></b> :: <b>  [ ˡ˥å ] 顼å </b>
   !
-  ! -1000   :: [ <b>USR_ECHAR          </b> ]
-  !            <b></b> :: <i>cause_c</i>
-  !
-  ! -1001   :: [ <b>USR_EINT           </b> ]
+  ! -1000 :: [ <b>USR_ERRNO           </b> ]
   !            <b></b> :: <i>cause_c</i> (<i>cause_i</i>)
   !
-  !
 
   use netcdf_f77, only: NF_ENOTVAR, NF_EINVAL
   implicit none
@@ -309,6 +306,7 @@ module dc_error
   integer, public, parameter   :: DC_NOERR  = 0
   integer, private, save       :: errno     = DC_NOERR
   integer, private, save       :: cause_int = DC_NOERR
+  logical, private, save       :: cause_int_valid = .false.
   character(80), private, save :: cause_string = ""
   character(80), private, save :: cause_location = ""
 
@@ -359,8 +357,7 @@ module dc_error
   !
   ! -1000 ʲ: 桼
   !
-  integer, parameter, public:: USR_ECHAR = -1000
-  integer, parameter, public:: USR_EINT  = -1001
+  integer, parameter, public:: USR_ERRNO = -1000
 
   public:: StoreError, DumpError, GetErrorMessage, ErrorCode
   !
@@ -387,9 +384,10 @@ contains
     ! ꤵƤ륨顼ɤбå֤ޤ
     !
     use netcdf_f77, only: nf_strerror
-    use dc_string , only: toChar
     character(len = *), intent(out):: msg
     character(len = 180):: message
+    character(len = 20):: errno_c
+    character(len = 20):: cause_int_c
   continue
     select case(errno)
     case(GT_EFAKE)
@@ -452,14 +450,21 @@ contains
       !
       ! -1000 ʲ: 桼
       !
-    case(USR_ECHAR)
-      msg = trim(cause_string)
-    case(USR_EINT)
-      msg = trim(cause_string) // ' (' // trim(toChar(cause_int)) // ')'
+    case(:USR_ERRNO)
+      if (len(trim(adjustl(cause_string))) < 1) then
+        cause_string = 'Unknown error'
+      end if
+      if (cause_int_valid) then
+        write(cause_int_c, "(i8)") cause_int
+        msg = trim(cause_string) // ' (' // trim(adjustl(cause_int_c)) // ')'
+      else
+        msg = trim(cause_string)
+      end if
     case default
       goto 999
     end select
-    msg =  '*** ERROR (Code ' // trim(toChar(errno))  // &
+    write(errno_c, "(i8)") errno
+    msg =  '*** ERROR (Code ' // trim(adjustl(errno_c))  // &
       & ') [' // trim(cause_location) // '] ***  ' // &
       & trim(msg)
     return
@@ -467,19 +472,23 @@ contains
 999 continue
     if (len(cause_string) > 0) then
       message = nf_strerror(errno)
-      msg =  '*** ERROR (Code ' // trim(toChar(errno)) // &
+      write(errno_c, "(i8)") errno
+      msg =  '*** ERROR (Code ' // trim(adjustl(errno_c)) // &
         & ') [' // trim(cause_location)             // &
         & '('   // trim(cause_string) // ')] ***  ' // &
         & trim(message)
-    else if (cause_int /= 0) then
+    else if (cause_int_valid) then
       message = nf_strerror(errno)
-      msg =  '*** ERROR (Code ' // trim(toChar(errno)) // &
+      write(errno_c, "(i8)") errno
+      write(cause_int_c, "(i8)") cause_int
+      msg =  '*** ERROR (Code ' // trim(adjustl(errno_c)) // &
         & ') [' // trim(cause_location)             // &
-        & '('   // trim(toChar(cause_int)) // ')] ***  ' // &
+        & '('   // trim(adjustl(cause_int_c)) // ')] ***  ' // &
         & trim(message)
     else
       message = nf_strerror(errno)
-      msg =  '*** ERROR (Code ' // trim(toChar(errno))  // &
+      write(errno_c, "(i8)") errno
+      msg =  '*** ERROR (Code ' // trim(adjustl(errno_c))  // &
         & ') [' // trim(cause_location) // '] ***  ' // &
         & trim(message)
     endif
@@ -502,17 +511,18 @@ contains
     !     *** ERROR (Code number) [where(cause_c)] ***  error_message
     !
     ! ʤgt4f90io  饤֥곰 桼顼ѥġ
-    ! Ȥ StoreError Ѥ뤳ȤꤷUSR_ECHAR  USR_EINT
-    ! ѰդƤޤ Υ顼ɤѤȡ
+    ! Ȥ StoreError Ѥ뤳ȤꤷUSR_ERRNO ֤꾮
+    ! 顼ɤ϶Ƥޤ<b><tt>USR_ERRNO</tt></b>
+    ! 꾮ͤ򥨥顼ɤͿ,
     ! StoreError ϰʲηʸ "*" ˽Ϥƥץ
     ! λޤ°פ˻ȤåϤӥ顼ȯ
     ! Υ⥸塼Ȥ *dc_message* ѰդƤΤ
     ! ⻲ȤƤ
     !
     !     
-    !     *** ERROR (Code USR_ECHAR) [where] ***  cause_c
+    !     *** ERROR (Code number) [where] ***  cause_c
     !     
-    !     *** ERROR (Code USR_EINT) [where] ***  cause_c (cause_i)
+    !     *** ERROR (Code number) [where] ***  cause_c (cause_i)
     !
     !--
     !== ȯԸ
@@ -545,7 +555,12 @@ contains
     else
       cause_string = ""
     endif
-    if (present(cause_i)) cause_int = cause_i
+    if (present(cause_i)) then
+      cause_int = cause_i
+      cause_int_valid = .true.
+    else
+      cause_int_valid = .false.
+    end if
     if (present(err)) then
       err = (number /= DC_NOERR)
       return
