@@ -1,8 +1,8 @@
 !== dc_message.f90 - åν
 !
 ! Authors::   Yasuhiro MORIKAWA, Masatsugu ODAKA
-! Version::   $Id: dc_message.f90,v 1.3 2006/06/03 16:58:32 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20070101 $
+! Version::   $Id: dc_message.f90,v 1.4 2007/01/08 06:30:37 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070116 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -69,12 +69,12 @@ contains
     ! Ϳ뤳ȤꤷƤޤ)
     ! Ϳ<b>̾Υå</b>Ǥ뤳Ȥꤷޤ
     ! <b><tt>"E"</tt></b>Ϳϥåϸ塢ץ
-    ! λޤ顼ɤ dc_error#USR_ECHAR Ȥʤޤ
+    ! λޤ顼ɤ dc_error#USR_ERRNO Ȥʤޤ
     !
 
     use dc_types  ,only: STRING, DP
     use dc_string ,only: UChar, StrHead, Printf, CPrintf
-    use dc_error  ,only: StoreError, USR_ECHAR
+    use dc_error  ,only: StoreError, USR_ERRNO
 
     implicit none
 
@@ -93,7 +93,7 @@ contains
     if (   StrHead(  'ERROR', trim( UChar(level) )  )   ) then
       msg = Cprintf(message, &
         &           i=i, r=r, d=d, L=L, n=n, c1=c1, c2=c2, c3=c3)
-      call StoreError(USR_ECHAR, where, cause_c=msg)
+      call StoreError(USR_ERRNO, where, cause_c=msg)
 
     elseif (   StrHead(  'WARNING', trim( UChar(level) )  )   ) then
       msg = Cprintf(message, &
@@ -125,7 +125,7 @@ contains
     !
     use dc_types  ,only: DP
     use dc_string ,only: CPrintf
-    use dc_error  ,only: StoreError, USR_ECHAR
+    use dc_error  ,only: StoreError, USR_ERRNO
 
     implicit none
 
